<?php
/**
 * Loulou66
 * LpsHomeTabCat module for Prestashop
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php*
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    Loulou66.fr <contact@loulou66.fr>
 *  @copyright loulou66.fr
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

class LpsHomeTabCatClass extends ObjectModel
{
    public $prod_category;

    public $prod_display;

    public $display_type;

    public $prod_visible;

    public $loop;

    public $autoplay;

    public $random;

    public $active;

    public $position;

    public $id_shop;

    public $title;

    public static $definition = [
        'table' => 'lpshometabcat',
        'primary' => 'id_lpshometabcat',
        'multilang' => true,
        'multilang_shop' => false,
        'fields' => [
            'prod_category' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt'],
            'prod_display' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt'],
            'display_type' => ['type' => self::TYPE_BOOL, 'validate' => 'isBool'],
            'prod_visible' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt'],
            'loop' => ['type' => self::TYPE_BOOL, 'validate' => 'isBool'],
            'autoplay' => ['type' => self::TYPE_BOOL, 'validate' => 'isBool'],
            'random' => ['type' => self::TYPE_BOOL, 'validate' => 'isBool'],
            'active' => ['type' => self::TYPE_BOOL, 'validate' => 'isBool'],
            'position' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt'],
            'id_shop' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedId'],
            'title' => [
                'type' => self::TYPE_STRING,
                'lang' => true,
                'validate' => 'isCatalogName',
                'size' => 128,
            ],
        ],
    ];

    public function add($autoDate = true, $nullValues = false)
    {
        if ($this->position <= 0) {
            $this->position = LpsHomeTabCatClass::getHigherPosition() + 1;
        }
        $this->id_shop = (int) Context::getContext()->shop->id;
        $autoDate = false;
        $return = parent::add($autoDate, $nullValues);
        return $return;
    }
    public static function getHigherPosition()
    {
        $sql = 'SELECT MAX(position) FROM `' . _DB_PREFIX_ . 'lpshometabcat`';
        $position = Db::getInstance()->getValue($sql);
        return is_numeric($position) ? $position : -1;
    }
    public function copyFromPost()
    {
        foreach ($_POST as $key => $value) {
            if (array_key_exists($key, get_object_vars($this)) and $key != 'id_' . $this->table) {
                $this->{$key} = $value;
            }
        }
        if (sizeof($this->fieldsValidateLang)) {
            $languages = Language::getLanguages(false);
            foreach ($languages as $lang) {
                foreach ($this->fieldsValidateLang as $field => $validation) {
                    $validation = $field;
                    if (Tools::isSubmit($field . '_' . (int) $lang['id_lang'])) {
                        $this->{$field}[(int) $lang['id_lang']] = Tools::getValue($field . '_' . (int) $lang['id_lang']);
                    }
                }
            }
        }
    }
    public static function updatePositions()
    {
        $positions = Tools::getValue('module-lpshometabcat');
        $new_positions = [];
        foreach ($positions as $v) {
            if (count(explode('_', $v)) == 4) {
                $new_positions[] = $v;
            }
        }
        foreach ($new_positions as $position => $value) {
            $pos = explode('_', $value);
            $lpshometabcat = new LpsHomeTabCatClass((int) $pos[2]);
            $lpshometabcat->position = $position;
            $lpshometabcat->save();
        }
    }
    public static function updatePositionsAfterDelete($id_lang, $id_shop)
    {
        $lpshometabcat = self::getAllTabs((int) $id_lang, (int) $id_shop);
        $position = 0;
        foreach ($lpshometabcat as $carousel) {
            $lpsHTC = new LpsHomeTabCatClass((int) $carousel['id_lpshometabcat']);
            $lpsHTC->position = $position;
            $lpsHTC->save();
            ++$position;
        }
    }
    public static function statusToggle($id_lpshometabcat)
    {
        $lpsHTC = new LpsHomeTabCatClass((int) $id_lpshometabcat);
        if (Validate::isLoadedObject($lpsHTC)) {
            $lpsHTC->active = !$lpsHTC->active;
            return $lpsHTC->update();
        } else {
            return false;
        }
    }
    public static function getAllTabs($id_lang, $id_shop)
    {
        $sql = 'SELECT lpshtc.*,  lpshtcl.*
            FROM `' . _DB_PREFIX_ . 'lpshometabcat` lpshtc
            LEFT JOIN `' . _DB_PREFIX_ . 'lpshometabcat_lang` lpshtcl
            ON (lpshtc.`id_lpshometabcat`= lpshtcl.`id_lpshometabcat`)
            WHERE lpshtc.`id_shop`=' . (int) $id_shop . '
            AND lpshtcl.`id_lang`=' . (int) $id_lang . '
            AND lpshtc.`active`= 1
            ORDER BY lpshtc.`position` ASC';
        return Db::getInstance()->executeS($sql);
    }
}
